@@ -4,6 +4,7 @@ Git repository manager.
 Installs, updates, and uninstalls large number of Git repositories
 """
 import os
+import os.path
 
 from fabric.api import local, lcd as cd
 
@@ -11,6 +12,7 @@ from fabric.api import local, lcd as cd
 def install(repo_dir, remote):
     """Install a git repo in a directory."""
     with cd(repo_dir):
+        print repo_dir
         local('git clone %s' % remote)
 
 
@@ -24,19 +26,23 @@ def install_remotes(repo_dir, remotesfilename):
 def update(repo_dir, repo=None):
     """Update a git repo in a directory."""
     if repo:
-        with cd(repo_dir):
-            with cd(repo):
-                local('git pull')
+        repo_path = os.path.join(repo_dir, repo)
+        with cd(repo_path):
+            print repo_path
+            local('git pull')
     else:
         for repo in os.listdir(repo_dir):
-            update(repo, repo_dir)
+            if os.path.isdir(os.path.join(repo_dir, repo)):
+                update(repo_dir, repo)
 
 
 def uninstall(repo_dir, repo=None):
     """Uninstall a git repo in a directory."""
     if repo:
         with cd(repo_dir):
+            print repo_dir
             local('rm -fr %s' % repo)
     else:
         for repo in os.listdir(repo_dir):
-            uninstall(repo_dir, repo)
+            if os.path.isdir(os.path.join(repo_dir, repo)):
+                uninstall(repo_dir, repo)
